/*
 * Copyright (C) 2021 Anton Romanov - All Rights Reserved
 * You may use, distribute and modify this code, please write to: romanov73@gmail.com.
 */

package ru.ulstu.extractor.service;

import org.springframework.stereotype.Service;
import ru.ulstu.extractor.model.Commit;
import ru.ulstu.extractor.repository.CommitRepository;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class CommitService {
    private final GitRepositoryService gitRepositoryService;
    private final CommitRepository commitRepository;
    private final AuthorService authorService;

    public CommitService(GitRepositoryService gitRepositoryService,
                         CommitRepository commitRepository,
                         AuthorService authorService) {
        this.gitRepositoryService = gitRepositoryService;
        this.commitRepository = commitRepository;
        this.authorService = authorService;
    }

    public void delete(List<Commit> commitsToRemove) {
        commitRepository.deleteAll(commitsToRemove);
    }

    public List<Commit> save(List<Commit> commits) {
        return commits.stream()
                .map(commit -> {
                    commit.setAuthor(authorService.findOrCreate(commit.getAuthor()));
                    return commitRepository.save(commit);
                }).collect(Collectors.toList());
    }

    public void deleteWithEmptyIds() {
        commitRepository.deleteByBranchIsNull();
    }
}


